@@ -30,7 +30,6 @@
 #define HAVE_DLFCN_H 1
 #define HAVE_EXECINFO_H 1
 #define HAVE_FCNTL_H 1
-#define HAVE_FCNTL_DIRECT 1
 #define HAVE_FENV_H 1
 #define HAVE_FLOAT_H 1
 #define HAVE_FNMATCH_H 1
@@ -73,7 +72,6 @@
 #define HAVE_SYS_IOCTL_H 1
 #define HAVE_SYS_MALLOC_H 1
 #define HAVE_SYS_MMAN_H 1
-/* #undef HAVE_SYS_MNTENT_H */
 /* #undef HAVE_SYS_NDIR_H */
 /* #undef HAVE_SYS_PTE_H */
 /* #undef HAVE_SYS_PTEM_H */
@@ -185,6 +183,7 @@
 #define HAVE_MLOCKALL 1
 #define HAVE_MMAP 1
 /* #undef HAVE_MMAP64 */
+#define HAVE_MPROTECT 1
 #define HAVE_PERROR 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_FALLOCATE 1
@@ -196,7 +195,6 @@
 #define HAVE_PTHREAD_ATTR_GETSTACKSIZE 1
 #define HAVE_PTHREAD_ATTR_SETSCOPE 1
 #define HAVE_PTHREAD_ATTR_SETSTACKSIZE 1
-#define HAVE_PTHREAD_GETATTR_NP 1
 /* #undef HAVE_PTHREAD_CONDATTR_CREATE */
 #define HAVE_PTHREAD_GETAFFINITY_NP 1
 #define HAVE_PTHREAD_KEY_DELETE 1
@@ -234,6 +232,7 @@
 #define HAVE_STRTOUL 1
 #define HAVE_STRTOULL 1
 /* #undef HAVE_TELL */
+/* #undef HAVE_THR_SETCONCURRENCY */
 /* #undef HAVE_THR_YIELD */
 #define HAVE_TIME 1
 #define HAVE_TIMES 1
@@ -335,7 +334,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-/* #undef WORDS_BIGENDIAN */
+#define WORDS_BIGENDIAN 1 
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -396,8 +395,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "NetBSD"
-#define MACHINE_TYPE "earmv6hf"
-#define DEFAULT_MACHINE "earmv6hf"
+#define MACHINE_TYPE "powerpc"
+#define DEFAULT_MACHINE "powerpc"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -500,7 +499,6 @@
 #define HAVE_COMPRESS 1
 #define HAVE_EncryptAes128Ctr 1
 #define HAVE_EncryptAes128Gcm 1
-#define HAVE_des 1
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -532,17 +530,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 23
+#define MYSQL_VERSION_MINOR 11
+#define MYSQL_VERSION_PATCH 6
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.6.23"
+#define PACKAGE_STRING "MySQL Server 10.11.6"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.6.23"
-#define VERSION "10.6.23"
+#define PACKAGE_VERSION "10.11.6"
+#define VERSION "10.11.6"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
